fireworks.user_objects.firetasks.tests package — FireWorks 1.4.4 documentation

# fireworks.user_objects.firetasks.tests package

## Submodules

## fireworks.user_objects.firetasks.tests.test_fileio_tasks module

class `fireworks.user_objects.firetasks.tests.test_fileio_tasks.` `CompressDecompressArchiveDirTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `tearDown`()
  `test_archive_dir`()
  `test_compress_dir`()

class `fireworks.user_objects.firetasks.tests.test_fileio_tasks.` `FileWriteDeleteTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_init`()
  `test_run`()

## fireworks.user_objects.firetasks.tests.test_filepad_tasks module

class `fireworks.user_objects.firetasks.tests.test_filepad_tasks.` `FilePadTasksTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()
  `tearDown`()
  `test_addfilesfrompatterntask_run`()
  `test_addfilestask_run`()
  `test_deletefilestask_run`()
  `test_getfilestask_run`()

## fireworks.user_objects.firetasks.tests.test_script_task module

class `fireworks.user_objects.firetasks.tests.test_script_task.` `PyTaskTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_task`()
  `test_task_auto_kwargs`()

class `fireworks.user_objects.firetasks.tests.test_script_task.` `ScriptTaskTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_scripttask`()

## fireworks.user_objects.firetasks.tests.test_templatewriter_task module

class `fireworks.user_objects.firetasks.tests.test_templatewriter_task.` `TemplateWriterTaskTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_task`()

## Module contents